function p=getCoronaParameters(country)
% fetch good parameters for Corona Analysis, depending on country
% Input country as string delivered e.g. from getCoronaCountryList.m
% just FYI: countrylist={ 'Germany' 'Brazil' 'Russia' 'Italy' 'Spain' 'Sweden' 'Austria' 
% 'France' 'UK','HongKong','US','Denmark','Switzerland'};
% actual list: see getCoronaCountryList.m
% Output:
% p=(tstart, N, estimateRecovered, timespan)
% OBSOLETE: tstart = day where systematic data start
% NEW: start at 10 deaths and 100 Confirmed at least, see the end
% N = total population (wikipedia)
% estimateRecovered = 1 if Recovered need estimation, 0 else
% Set to 1 it the Recovered data of the country are a mess
% timespan = number of days for future predicton
timespan=100; % standard value, about 3 months
switch country
    case 'Brazil'
        tstart=65;
        N=210e6;
        estimateRecovered=1;
        timespan=350;
    case 'Russia'
        tstart=70;
        N=144e6;
        estimateRecovered=0;
        timespan=350;
    case 'Denmark'
        tstart=65;
        N=5.8e6;
        estimateRecovered=1;
    case 'Switzerland'
        tstart=55;
        N=8.6e6;
        estimateRecovered=1;
    case 'Hubei'
        tstart=8;
        N=58e6;
        estimateRecovered=0;
    case 'Korea'
        tstart=31;
        N=51e6;
        estimateRecovered=0;
    case 'Germany'
        tstart=40;
        N=83e6;
        estimateRecovered=0;
    case 'Italy'
        tstart=35;
        N=60e6;
        estimateRecovered=0;
    case 'France'
        tstart=38;
        N=67e6;
        estimateRecovered=0;
    case 'Spain'
        tstart=35;
        N=46.6e6;
        estimateRecovered=0;
    case 'UK'
        tstart=38;
        N=67.5e6;
        estimateRecovered=1;
        timespan=200;        
    case 'Austria'
        tstart=31;
        N=8.95e6;
        estimateRecovered=0;
    case 'Sweden'
        tstart=43;
        N=10e6;
        estimateRecovered=1;
        timespan=350;      
    case 'HongKong'
        tstart=24;
        N=7.4e6;
        estimateRecovered=0;
    case 'US'
        tstart=40;
        N=372e6;
        estimateRecovered=0;
        timespan=450;       
    otherwise
        disp('Country not implemented, needs parameters')
        return   
end
[C, R, D]=getCoronaData(country);
tstart=1;
% make sure that D >= 10 and C >= 100 
% D and C are cumulative !
fD=find(D>=10);
fC=find(C>=100);
if length(fD)>0
    tstart=max(tstart,min(fD));
end
if length(fC)>0
    tstart=max(tstart,min(fC));
end
% set the parameter list
p(1)=tstart;
p(2)=N;
p(3)=estimateRecovered;
p(4)=timespan;
