function [beta, gam, b]=getbetagammafromSMHCN(S, M, H, C, N)
%
% gets gamma, beta, and b from the hidden model as sequences
%
% Input vectors are all of same length, 
% as output vectors will be
% 
% N = population size
%
% The output vectors will contain zeros in case that 
% division by zero is avoided.  
%
len=length(C);
% allocate output vectors
gam  =zeros(len,1);
beta =zeros(len,1);
b    =zeros(len,1);
% get differences of C, H and S 
dC=zeros(len,1);
dH=zeros(len,1);
dS=zeros(len,1);
dH(2:len)=H(2:len)-H(1:len-1);
dC(2:len)=C(2:len)-C(1:len-1);
dS(2:len)=S(2:len)-S(1:len-1);
% Note that the first value of a difference vector will be zero
% avoid division by zero for M
tM=find(M>=1);
% get gamma as in paper
gam(tM)=(dC(tM)+dH(tM))./M(tM);
% avoid division by zero for S
tS=find(S>=1);
% and take intersection
tMtS=intersect(tM,tS);
% now beta and b as in the paper
b(tMtS)=-dS(tMtS)./M(tMtS);
beta(tMtS)=b(tMtS)*N./S(tMtS);
